ToTokens

Trait ToTokens 

pub trait ToTokens {
    // Required method
    fn to_tokens(&self, tokens: &mut TokenStream);

    // Provided methods
    fn to_token_stream(&self) -> TokenStream { ... }
    fn into_token_stream(self) -> TokenStream
       where Self: Sized { ... }
}
Types that can be interpolated inside a quote! invocation.

Required Methods

fn to_tokens(&self, tokens: &mut TokenStream)

Write self to the given TokenStream.

The token append methods provided by the TokenStreamExt extension trait may be useful for implementing ToTokens.

Example

Example implementation for a struct representing Rust paths like std::cmp::PartialEq:

use proc_macro2::{TokenTree, Spacing, Span, Punct, TokenStream};
use quote::{TokenStreamExt, ToTokens};

pub struct Path {
    pub global: bool,
    pub segments: Vec<PathSegment>,
}

impl ToTokens for Path {
    fn to_tokens(&self, tokens: &mut TokenStream) {
        for (i, segment) in self.segments.iter().enumerate() {
            if i > 0 || self.global {
                // Double colon `::`
                tokens.append(Punct::new(':', Spacing::Joint));
                tokens.append(Punct::new(':', Spacing::Alone));
            }
            segment.to_tokens(tokens);
        }
    }
}

Provided Methods

fn to_token_stream(&self) -> TokenStream

Convert self directly into a TokenStream object.

This method is implicitly implemented using to_tokens, and acts as a convenience method for consumers of the ToTokens trait.

fn into_token_stream(self) -> TokenStream
where Self: Sized,

Convert self directly into a TokenStream object.

This method is implicitly implemented using to_tokens, and acts as a convenience method for consumers of the ToTokens trait.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToTokens for CStr

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for CString

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for Group

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for Ident

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for Literal

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for Punct

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for String

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for TokenStream

Source

impl ToTokens for TokenTree

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for bool

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for char

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for f32

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for f64

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for i8

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for i16

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for i32

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for i64

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for i128

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for isize

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for str

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for u8

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for u16

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for u32

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for u64

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for u128

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl ToTokens for usize

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<'a, T: ?Sized + ToOwned + ToTokens> ToTokens for Cow<'a, T>

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ?Sized + ToTokens> ToTokens for &T

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ?Sized + ToTokens> ToTokens for &mut T

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ?Sized + ToTokens> ToTokens for Arc<T>

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ?Sized + ToTokens> ToTokens for Box<T>

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ?Sized + ToTokens> ToTokens for Rc<T>

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Source

impl<T: ToTokens> ToTokens for Option<T>

Source

fn to_tokens(&self, tokens: &mut TokenStream)

Implementors